package anychart.examples.java;

import org.eclipse.swt.SWT;
import org.eclipse.swt.SWTError;
import org.eclipse.swt.browser.*;
import org.eclipse.swt.layout.*;
import org.eclipse.swt.widgets.*;

public class Example1 {
    /**
     * Text area with event logs.
     */
    static Text text;

    /**
     * Script that executes on button click.
     */
    static String myScript = "window.dataSet.append(Math.floor(Math.random() * 10 + 1));" +
            "if (window.dataSet.getRowsCount() > 20) dataSet.remove(0)";

    static String createHTML() {
        return "<html>\n" +
                "<head>\n" +
                "    <script src=\"https://cdn.anychart.com/js/latest/anychart.min.js\"></script>\n" +
                "    <script>\n" +
                "        anychart.onDocumentReady(function() {\n" +
                "            window.dataSet = anychart.data.set([1, 3, 2, 5, 8]);\n" +
                "            chart = anychart.line(dataSet);\n" +
                "            chart.container('container');\n" +
                "            chart.draw();\n" +
                "            chart.listen('chartdraw', function(e) {\n" +
                "                window.logEvent(e.type);\n" +
                "            });\n" +
                "            chart.listen('pointmouseover', function(e) {\n" +
                "                window.logEvent(e.type, e.pointIndex);\n" +
                "            });\n" +
                "        });\n" +
                "    </script>\n" +
                "    <style>\n" +
                "        html, body, #container {\n" +
                "            width: 400px;\n" +
                "            height: 300px;\n" +
                "            margin: 0;\n" +
                "        }\n" +
                "    </style>\n" +
                "</head>\n" +
                "<body>\n" +
                "<div id=\"container\"></div>\n" +
                "</body>\n" +
                "</html>\n";
    }

    public static void main(String[] args) {
        Display display = new Display();

        Shell shell = new Shell(display, SWT.SHELL_TRIM | SWT.CENTER);
        shell.setText("Application title");
        shell.setSize(1200, 768);
        shell.setLayout(new GridLayout(2, false));

        Button button = new Button(shell, SWT.PUSH);
        button.setText("Add Random Point");

        final Browser browser;
        try {
            browser = new Browser(shell, SWT.NONE);
        } catch (SWTError e) {
            System.out.println("Could not instantiate Browser: " + e.getMessage());
            display.dispose();
            return;
        }
        browser.setText(createHTML());

        button.addListener(SWT.Selection, new Listener() {
            @Override
            public void handleEvent(Event event) {
                boolean result = browser.execute(myScript);
                if (!result) {
                    /* Script may fail or may not be supported on certain platforms. */
                    System.out.println("Script was not executed.");
                }
            }
        });

        GridData gd2 = new GridData(SWT.FILL, SWT.FILL, true, true);
        gd2.verticalSpan = 2;
        browser.setLayoutData(gd2);

        text = new Text(shell, SWT.MULTI | SWT.BORDER | SWT.WRAP | SWT.V_SCROLL);
        text.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));

        // logEvent - name of function that will be called from JavaScript
        new CustomFunction(browser, "logEvent");

        shell.open();

        while (!shell.isDisposed()) {
            if (!display.readAndDispatch()) {
                display.sleep();
            }
        }
        display.dispose();
    }

    /**
     * Class responsible for interaction with JavaScript
     */
    static class CustomFunction extends BrowserFunction {
        CustomFunction(Browser browser, String name) {
            super(browser, name);
        }

        @Override
        public Object function(Object[] arguments) {
            // handling javascript call

            if (arguments[0].toString().equals("pointmouseover")) {
                int pointIndex = ((Double) arguments[1]).intValue();
                text.append(arguments[0].toString() + " on index " + pointIndex + "\n");
            } else {
                text.append(arguments[0].toString() + "\n");
            }
            return null;
        }
    }
}
